@@ -21,16 +21,15 @@
 
 #include "sieveactionabstractflags.h"
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveActionAddFlags : public SieveActionAbstractFlags
 {
     Q_OBJECT
 public:
     explicit SieveActionAddFlags(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent = nullptr);
-    QString flagsCode() const Q_DECL_OVERRIDE;
-    QString help() const Q_DECL_OVERRIDE;
-    QUrl href() const Q_DECL_OVERRIDE;
+    QString flagsCode() const override;
+    QString help() const override;
+    QUrl href() const override;
 };
 }
 #endif // SIEVEACTIONADDFLAGS_H
