@@ -20,21 +20,20 @@
 #define SIEVEACTIONFILEINTO_H
 #include "sieveaction.h"
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveActionFileInto : public SieveAction
 {
     Q_OBJECT
 public:
     explicit SieveActionFileInto(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent = nullptr);
-    QString code(QWidget *) const Q_DECL_OVERRIDE;
-    QWidget *createParamWidget(QWidget *parent) const Q_DECL_OVERRIDE;
-    QStringList needRequires(QWidget *parent) const Q_DECL_OVERRIDE;
-    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, QString &error) Q_DECL_OVERRIDE;
-    bool needCheckIfServerHasCapability() const Q_DECL_OVERRIDE;
-    QString serverNeedsCapability() const Q_DECL_OVERRIDE;
-    QString help() const Q_DECL_OVERRIDE;
-    QUrl href() const Q_DECL_OVERRIDE;
+    QString code(QWidget *) const override;
+    QWidget *createParamWidget(QWidget *parent) const override;
+    QStringList needRequires(QWidget *parent) const override;
+    bool setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, QString &error) override;
+    bool needCheckIfServerHasCapability() const override;
+    QString serverNeedsCapability() const override;
+    QString help() const override;
+    QUrl href() const override;
 
 private:
     bool mHasCopySupport;
