@@ -21,9 +21,7 @@
 
 #include <QLineEdit>
 
-namespace KSieveUi
-{
-
+namespace KSieveUi {
 class AddressLineEdit : public QLineEdit
 {
     Q_OBJECT
@@ -35,7 +33,7 @@ Q_SIGNALS:
     void valueChanged();
 
 protected:
-    void focusOutEvent(QFocusEvent *ev) Q_DECL_OVERRIDE;
+    void focusOutEvent(QFocusEvent *ev) override;
 
 private:
     void slotTextChanged();
