@@ -21,8 +21,7 @@
 
 #include "kpimtextedit/plaintexteditor.h"
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class MultiLineEdit : public KPIMTextEdit::PlainTextEditor
 {
     Q_OBJECT
@@ -34,8 +33,8 @@ Q_SIGNALS:
     void valueChanged();
 
 protected:
-    QSize sizeHint() const Q_DECL_OVERRIDE;
-    QSize minimumSizeHint() const Q_DECL_OVERRIDE;
+    QSize sizeHint() const override;
+    QSize minimumSizeHint() const override;
 };
 }
 
