@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,21 +24,16 @@
 
 #include <QHBoxLayout>
 #include <QComboBox>
-#include <QDomNode>
+#include <QXmlStreamReader>
 #include "libksieve_debug.h"
 
 using namespace KSieveUi;
 
-SieveConditionSize::SieveConditionSize(QObject *parent)
-    : SieveCondition(QStringLiteral("size"), i18n("Size"), parent)
+SieveConditionSize::SieveConditionSize(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveCondition(sieveGraphicalModeWidget, QStringLiteral("size"), i18n("Size"), parent)
 {
 }
 
-SieveCondition *SieveConditionSize::newAction()
-{
-    return new SieveConditionSize;
-}
-
 QWidget *SieveConditionSize::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
@@ -66,7 +61,7 @@ QString SieveConditionSize::code(QWidget *w) const
     const QComboBox *combo = w->findChild<QComboBox *>(QStringLiteral("combosize"));
     const QString comparaison = combo->itemData(combo->currentIndex()).toString();
     const SelectSizeWidget *sizeWidget = w->findChild<SelectSizeWidget *>(QStringLiteral("sizewidget"));
-    return QStringLiteral("size %1 %2").arg(comparaison, sizeWidget->code());
+    return QStringLiteral("size %1 %2").arg(comparaison, sizeWidget->code()) + AutoCreateScriptUtil::generateConditionComment(comment());
 }
 
 QString SieveConditionSize::help() const
@@ -74,39 +69,40 @@ QString SieveConditionSize::help() const
     return i18n("The \"size\" test deals with the size of a message.  It takes either a tagged argument of \":over\" or \":under\", followed by a number representing the size of the message.");
 }
 
-bool SieveConditionSize::setParamWidgetValue(const QDomElement &element, QWidget *w, bool /*notCondition*/, QString &error)
+bool SieveConditionSize::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool /*notCondition*/, QString &error)
 {
-    QDomNode node = element.firstChild();
-    while (!node.isNull()) {
-        QDomElement e = node.toElement();
-        if (!e.isNull()) {
-            const QString tagName = e.tagName();
-            if (tagName == QLatin1String("tag")) {
-                const QString tagValue = e.text();
-                QComboBox *combo = w->findChild<QComboBox *>(QStringLiteral("combosize"));
-                const int index = combo->findData(AutoCreateScriptUtil::tagValue(tagValue));
-                if (index != -1) {
-                    combo->setCurrentIndex(index);
-                }
-            } else if (tagName == QLatin1String("num")) {
-                const qlonglong tagValue = e.text().toLongLong();
-                QString numIdentifier;
-                if (e.hasAttribute(QStringLiteral("quantifier"))) {
-                    numIdentifier = e.attribute(QStringLiteral("quantifier"));
-                }
-                SelectSizeWidget *sizeWidget = w->findChild<SelectSizeWidget *>(QStringLiteral("sizewidget"));
-                sizeWidget->setCode(tagValue, numIdentifier, name(), error);
-            } else if (tagName == QLatin1String("crlf")) {
-                //nothing
-            } else if (tagName == QLatin1String("comment")) {
-                //implement in the future ?
-            } else {
-                unknownTag(tagName, error);
-                qCDebug(LIBKSIEVE_LOG) << " SieveConditionSize::setParamWidgetValue unknown tagName " << tagName;
+    QString commentStr;
+    while (element.readNextStartElement()) {
+        const QStringRef tagName = element.name();
+        if (tagName == QLatin1String("tag")) {
+            const QString tagValue = element.readElementText();
+            QComboBox *combo = w->findChild<QComboBox *>(QStringLiteral("combosize"));
+            const int index = combo->findData(AutoCreateScriptUtil::tagValue(tagValue));
+            if (index != -1) {
+                combo->setCurrentIndex(index);
             }
+        } else if (tagName == QLatin1String("num")) {
+            QString numIdentifier;
+            if (element.attributes().hasAttribute(QStringLiteral("quantifier"))) {
+                numIdentifier = element.attributes().value(QStringLiteral("quantifier")).toString();
+            }
+            const qlonglong tagValue = element.readElementText().toLongLong();
+            SelectSizeWidget *sizeWidget = w->findChild<SelectSizeWidget *>(QStringLiteral("sizewidget"));
+            sizeWidget->setCode(tagValue, numIdentifier, name(), error);
+        } else if (tagName == QLatin1String("crlf")) {
+            element.skipCurrentElement();
+            //nothing
+        } else if (tagName == QLatin1String("comment")) {
+            commentStr = AutoCreateScriptUtil::loadConditionComment(commentStr, element.readElementText());
+        } else {
+            unknownTag(tagName, error);
+            qCDebug(LIBKSIEVE_LOG) << " SieveConditionSize::setParamWidgetValue unknown tagName " << tagName;
         }
-        node = node.nextSibling();
     }
+    if (!commentStr.isEmpty()) {
+        setComment(commentStr);
+    }
+
     return true;
 }
 
