@@ -21,8 +21,7 @@
 
 #include <QComboBox>
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveEditorGraphicalModeWidget;
 class SelectAddressPartComboBox : public QComboBox
 {
