@@ -26,12 +26,13 @@
 
 #include <KLocalizedString>
 #include <QLineEdit>
+#include "widgets/lineeditvalidator.h"
 
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QCheckBox>
 #include <QWhatsThis>
-#include <QDomNode>
+#include <QXmlStreamReader>
 #include "libksieve_debug.h"
 
 using namespace KSieveUi;
@@ -39,31 +40,27 @@ using namespace KSieveUi;
 SieveForEveryPartWidget::SieveForEveryPartWidget(QWidget *parent)
     : SieveWidgetPageAbstract(parent)
 {
-    QVBoxLayout *topLayout = new QVBoxLayout(this);
-
-    QWidget *w = new QWidget;
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
     QHBoxLayout *lay = new QHBoxLayout;
-    lay->setMargin(0);
-    w->setLayout(lay);
+    mainLayout->addLayout(lay);
+    mainLayout->addStretch(1);
 
     mHelpButton = new SieveHelpButton;
-    topLayout->addWidget(mHelpButton);
+    lay->addWidget(mHelpButton);
     connect(mHelpButton, &SieveHelpButton::clicked, this, &SieveForEveryPartWidget::slotHelp);
 
     mForLoop = new QCheckBox(i18n("Add ForEveryPart loop"));
     connect(mForLoop, &QCheckBox::toggled, this, &SieveForEveryPartWidget::valueChanged);
-    topLayout->addWidget(mForLoop);
+    lay->addWidget(mForLoop);
 
     QLabel *lab = new QLabel(i18n("Name (optional):"));
     lay->addWidget(lab);
 
-    mName = new QLineEdit;
+    mName = new LineEditValidator;
     connect(mName, &QLineEdit::textChanged, this, &SieveForEveryPartWidget::valueChanged);
     mName->setEnabled(false);
     lay->addWidget(mName);
 
-    topLayout->addWidget(w, 0, Qt::AlignTop);
-
     connect(mForLoop, &QCheckBox::clicked, mName, &QLineEdit::setEnabled);
     setPageType(KSieveUi::SieveScriptBlockWidget::ForEveryPart);
 }
@@ -74,45 +71,49 @@ SieveForEveryPartWidget::~SieveForEveryPartWidget()
 
 void SieveForEveryPartWidget::slotHelp()
 {
-    const QString help = i18n("\"foreverypart\", which is an iterator that walks though every MIME part of a message, including nested parts, depth first, and applies the commands in the specified block to each of them.");
+    const QString help = i18n(
+        "\"foreverypart\", which is an iterator that walks though every MIME part of a message, including nested parts, depth first, and applies the commands in the specified block to each of them.");
     const QUrl href = KSieveUi::SieveEditorUtil::helpUrl(KSieveUi::SieveEditorUtil::ForEveryPart);
     const QString fullWhatsThis = AutoCreateScriptUtil::createFullWhatsThis(help, href.toString());
     QWhatsThis::showText(QCursor::pos(), fullWhatsThis, mHelpButton);
 }
 
-void SieveForEveryPartWidget::generatedScript(QString &script, QStringList &requires)
+void SieveForEveryPartWidget::generatedScript(QString &script, QStringList &requires, bool inForEveryPartLoop)
 {
+    Q_UNUSED(inForEveryPartLoop);
     if (mForLoop->isChecked()) {
         requires << QStringLiteral("foreverypart");
         const QString loopName = mName->text();
         if (loopName.isEmpty()) {
-            script += QLatin1String("foreverypart {");
+            script += QStringLiteral("foreverypart {");
         } else {
             script += QStringLiteral("foreverypart :name \"%1\" {").arg(loopName);
         }
     }
 }
 
-void SieveForEveryPartWidget::loadScript(const QDomElement &element, QString &error)
+void SieveForEveryPartWidget::loadScript(QXmlStreamReader &element, QString &error)
 {
-    QDomNode node = element.firstChild();
-    QDomElement e = node.toElement();
-    if (!e.isNull()) {
-        const QString tagName = e.tagName();
-        if (tagName == QLatin1String("tag")) {
-            const QString tagValue = e.text();
-            if (tagValue == QLatin1String("name")) {
-                mName->setText(AutoCreateScriptUtil::strValue(e));
-            } else {
-                error += i18n("Unknown tagValue \"%1\" during loading loop \"for\"", tagValue) + QLatin1Char('\n');
-                qCDebug(LIBKSIEVE_LOG) << " SieveForEveryPartWidget::loadScript unknown tagValue " << tagValue;
-            }
-            mForLoop->setChecked(true);
-            mName->setEnabled(true);
+    element.readNextStartElement();
+    const QStringRef tagName = element.name();
+    if (tagName == QLatin1String("tag")) {
+        const QString tagValue = element.readElementText();
+        if (tagValue == QLatin1String("name")) {
+            mName->setText(AutoCreateScriptUtil::strValue(element));
         } else {
-            error += i18n("Unknown tag \"%1\" during loading loop \"for\"", tagName) + QLatin1Char('\n');
-            qCDebug(LIBKSIEVE_LOG) << " SieveForEveryPartWidget::loadScript unknown tagName " << tagName;
+            error += i18n("Unknown tagValue \"%1\" during loading loop \"for\"", tagValue) + QLatin1Char('\n');
+            qCDebug(LIBKSIEVE_LOG) << " SieveForEveryPartWidget::loadScript unknown tagValue " << tagValue;
         }
+        mForLoop->setChecked(true);
+        mName->setEnabled(true);
+    } else if (tagName == QLatin1String("block")) {
+        //Nothing
+        //It's when name is empty
+    } else if (tagName == QLatin1String("crlf")) {
+        //Nothing
+        element.skipCurrentElement();
+    } else {
+        error += i18n("Unknown tag \"%1\" during loading loop \"for\"", tagName.toString()) + QLatin1Char('\n');
+        qCDebug(LIBKSIEVE_LOG) << " SieveForEveryPartWidget::loadScript unknown tagName " << tagName;
     }
 }
-
