@@ -23,10 +23,9 @@
 #include "sievewidgetpageabstract.h"
 class QCheckBox;
 class QLineEdit;
-class QDomElement;
+class QXmlStreamReader;
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveHelpButton;
 class SieveForEveryPartWidget : public SieveWidgetPageAbstract
 {
@@ -35,8 +34,8 @@ public:
     explicit SieveForEveryPartWidget(QWidget *parent = nullptr);
     ~SieveForEveryPartWidget();
 
-    void generatedScript(QString &script, QStringList &requires) Q_DECL_OVERRIDE;
-    void loadScript(const QDomElement &element, QString &error);
+    void generatedScript(QString &script, QStringList &requires, bool inForEveryPartLoop) override;
+    void loadScript(QXmlStreamReader &element, QString &error);
 
 private Q_SLOTS:
     void slotHelp();
