@@ -148,6 +148,7 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     mDebugTextEdit = new KPIMTextEdit::PlainTextEditorWidget;
     mDebugTextEdit->editor()->setSearchSupport(false);
     mDebugTextEdit->editor()->setReadOnly(true);
+    mDebugTextEdit->editor()->setPlaceholderText(i18n("Show result from \"check syntax\""));
     mMainSplitter->addWidget(mTemplateSplitter);
     mMainSplitter->addWidget(mDebugTextEdit);
     mMainSplitter->setChildrenCollapsible(false);
@@ -217,12 +218,12 @@ void SieveEditorTextModeWidget::generateXml()
     const QByteArray script = mTextEdit->toPlainText().toUtf8();
     KSieve::Parser parser(script.begin(),
                           script.begin() + script.length());
-    KSieveUi::XMLPrintingScriptBuilder psb;
+    KSieveUi::XMLPrintingScriptBuilder psb(2);
     parser.setScriptBuilder(&psb);
     const bool result = parser.parse();
     QPointer<ParsingResultDialog> dlg = new ParsingResultDialog(this);
     if (result) {
-        dlg->setResultParsing(psb.toDom().toString());
+        dlg->setResultParsing(psb.result());
     } else {
         dlg->setResultParsing(i18n("Error during parsing"));
     }
@@ -374,9 +375,12 @@ void SieveEditorTextModeWidget::print()
 
         std::unique_ptr<QPrintDialog> dlg(new QPrintDialog(&printer));
 
+        bool restoreSpellCheck = mTextEdit->checkSpellingEnabled();
+        mTextEdit->setCheckSpellingEnabled(false);
         if (dlg && dlg->exec() == QDialog::Accepted) {
             mTextEdit->print(&printer);
         }
+        mTextEdit->setCheckSpellingEnabled(restoreSpellCheck);
     }
 }
 
@@ -384,12 +388,14 @@ void SieveEditorTextModeWidget::printPreview()
 {
     const QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
-
+        bool restoreSpellCheck = mTextEdit->checkSpellingEnabled();
+        mTextEdit->setCheckSpellingEnabled(false);
         PimCommon::KPimPrintPreviewDialog previewdlg(this);
-        connect(&previewdlg, &QPrintPreviewDialog::paintRequested, this, [this](QPrinter * printer) {
+        connect(&previewdlg, &QPrintPreviewDialog::paintRequested, this, [this](QPrinter *printer) {
             mTextEdit->print(printer);
         });
         previewdlg.exec();
+        mTextEdit->setCheckSpellingEnabled(restoreSpellCheck);
     }
 }
 
@@ -571,7 +577,7 @@ void SieveEditorTextModeWidget::debugSieveScript()
 bool SieveEditorTextModeWidget::isTextEditor() const
 {
     const QWidget *w = mTabWidget->currentWidget();
-    return (w == mEditorWidget);
+    return w == mEditorWidget;
 }
 
 bool SieveEditorTextModeWidget::printSupportEnabled() const
