@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2017 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -31,6 +31,7 @@ public:
         : mIsActive(false)
     {
     }
+
     QString mNewName;
     QUrl mOldUrl;
     QUrl mNewUrl;
@@ -38,10 +39,9 @@ public:
 };
 
 RenameScriptJob::RenameScriptJob(QObject *parent)
-    : QObject(parent),
-      d(new RenameScriptJobPrivate)
+    : QObject(parent)
+    , d(new RenameScriptJobPrivate)
 {
-
 }
 
 RenameScriptJob::~RenameScriptJob()
