@@ -42,8 +42,8 @@
 using namespace KSieveUi;
 
 SieveScriptDebuggerFrontEndWidget::SieveScriptDebuggerFrontEndWidget(QWidget *parent)
-    : QWidget(parent),
-      mProcess(nullptr)
+    : QWidget(parent)
+    , mProcess(nullptr)
 {
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->setMargin(0);
@@ -90,7 +90,7 @@ SieveScriptDebuggerFrontEndWidget::SieveScriptDebuggerFrontEndWidget(QWidget *pa
     vboxSieveEditorLayout->addWidget(textToSpeechWidget);
 
     KSieveUi::SieveScriptDebuggerTextEdit *textEdit = new KSieveUi::SieveScriptDebuggerTextEdit(this);
-    connect(textEdit, &KSieveUi::SieveScriptDebuggerTextEdit::textChanged, this, &SieveScriptDebuggerFrontEndWidget::scriptTextChanged);
+    connect(textEdit, &KSieveUi::SieveScriptDebuggerTextEdit::textChanged, this, &SieveScriptDebuggerFrontEndWidget::slotScriptTextChanged);
     mSieveTextEditWidget = new KSieveUi::SieveTextEditWidget(textEdit, this);
     mSieveTextEditWidget->setObjectName(QStringLiteral("sievetexteditwidget"));
     vboxSieveEditorLayout->addWidget(mSieveTextEditWidget);
@@ -101,6 +101,7 @@ SieveScriptDebuggerFrontEndWidget::SieveScriptDebuggerFrontEndWidget(QWidget *pa
 
     mSieveTestResult = new KPIMTextEdit::PlainTextEditorWidget(new KSieveUi::SieveScriptDebuggerResultEditor(this), this);
     mSieveTestResult->setObjectName(QStringLiteral("sievetextresult"));
+    mSieveTestResult->editor()->setPlaceholderText(i18n("Display check script result..."));
     mSieveTestResult->setReadOnly(true);
     mSplitter->addWidget(mSieveTestResult);
 
@@ -120,7 +121,19 @@ SieveScriptDebuggerFrontEndWidget::SieveScriptDebuggerFrontEndWidget(QWidget *pa
 
 SieveScriptDebuggerFrontEndWidget::~SieveScriptDebuggerFrontEndWidget()
 {
+    disconnect(mSieveTextEditWidget->textEdit(), &KSieveUi::SieveScriptDebuggerTextEdit::textChanged, this, &SieveScriptDebuggerFrontEndWidget::slotScriptTextChanged);
+}
 
+
+void SieveScriptDebuggerFrontEndWidget::updateDebugButton()
+{
+    mDebugScript->setEnabled(!mSieveTextEditWidget->textEdit()->document()->isEmpty() && !mEmailPath->lineEdit()->text().trimmed().isEmpty());
+}
+
+void SieveScriptDebuggerFrontEndWidget::slotScriptTextChanged()
+{
+    updateDebugButton();
+    Q_EMIT scriptTextChanged();
 }
 
 void SieveScriptDebuggerFrontEndWidget::setSplitterSizes(const QList<int> &sizes)
@@ -135,7 +148,8 @@ QList<int> SieveScriptDebuggerFrontEndWidget::splitterSizes() const
 
 void SieveScriptDebuggerFrontEndWidget::slotEmailChanged(const QString &text)
 {
-    mDebugScript->setEnabled(!text.trimmed().isEmpty());
+    Q_UNUSED(text);
+    updateDebugButton();
 }
 
 void SieveScriptDebuggerFrontEndWidget::slotDebugScript()
@@ -229,4 +243,3 @@ bool SieveScriptDebuggerFrontEndWidget::canAccept() const
     mSieveScriptDebuggerWarning->hide();
     return true;
 }
-
