@@ -37,27 +37,40 @@
 *******************************************************************************/
 
 #include "util.h"
-#include "PimCommon/PimUtil"
+#include "util_p.h"
+#include "libksieve_debug.h"
+#include <PimCommon/PimUtil>
 #include "imapresourcesettings.h"
+#include "sieveimappasswordprovider.h"
 #include "sieve-vacation.h"
+#include "sieveimapinstance/sieveimapinstanceinterfacemanager.h"
+#include "sieveimapinstance/sieveimapinstance.h"
+#include "akonadiimapsettinginterface.h"
 
-#include <agentmanager.h>
 #include <kmime/kmime_message.h>
-#include <MailTransport/mailtransport/transport.h>
+#include <mailtransport/transport.h>
 #include <QUrlQuery>
 
 using namespace KSieveUi;
 
-QUrl KSieveUi::Util::findSieveUrlForAccount(const QString &identifier, bool withVacationFileName)
+KSieveUi::Util::AccountInfo KSieveUi::Util::fullAccountInfo(const QString &identifier, SieveImapPasswordProvider *provider, bool withVacationFileName)
 {
-    QScopedPointer<OrgKdeAkonadiImapSettingsInterface> interface(PimCommon::Util::createImapSettingsInterface(identifier));
+    std::unique_ptr<OrgKdeAkonadiImapSettingsInterface> interfaceImap(PimCommon::Util::createImapSettingsInterface(identifier));
+    std::unique_ptr<KSieveUi::AbstractAkonadiImapSettingInterface> interface(new KSieveUi::AkonadiImapSettingInterface(interfaceImap));
+    KSieveUi::Util::AccountInfo accountInfo = KSieveUi::Util::findAccountInfo(identifier, provider, withVacationFileName, interface);
+    return accountInfo;
+}
 
+KSieveUi::Util::AccountInfo KSieveUi::Util::findAccountInfo(const QString &identifier, SieveImapPasswordProvider *provider, bool withVacationFileName,
+                                                            std::unique_ptr<KSieveUi::AbstractAkonadiImapSettingInterface> &interface)
+{
+    KSieveUi::Util::AccountInfo accountInfo;
     if (!interface) {
-        return QUrl();
+        return accountInfo;
     }
 
     if (!interface->sieveSupport()) {
-        return QUrl();
+        return accountInfo;
     }
 
     if (interface->sieveReuseConfig()) {
@@ -65,26 +78,27 @@ QUrl KSieveUi::Util::findSieveUrlForAccount(const QString &identifier, bool with
         QUrl u;
         u.setScheme(QStringLiteral("sieve"));
         QString server;
-        QDBusReply<QString> reply = interface->imapServer();
-        if (reply.isValid()) {
+        QString reply = interface->imapServer();
+        if (!reply.isEmpty()) {
             server = reply;
             server = server.section(QLatin1Char(':'), 0, 0);
         } else {
-            return QUrl();
+            return accountInfo;
         }
+        const QString userName = interface->userName();
+        accountInfo.sieveImapAccountSettings.setServerName(server);
+        accountInfo.sieveImapAccountSettings.setUserName(userName);
+
         u.setHost(server);
-        u.setUserName(interface->userName());
+        u.setUserName(userName);
 
-        QDBusInterface resourceSettings(QLatin1String("org.freedesktop.Akonadi.Resource.") + identifier, QStringLiteral("/Settings"), QStringLiteral("org.kde.Akonadi.Imap.Wallet"));
-
-        QString pwd;
-        QDBusReply<QString> replyPass = resourceSettings.call(QStringLiteral("password"));
-        if (replyPass.isValid()) {
-            pwd = replyPass;
-        }
+        const QString pwd = provider->password(identifier);
         u.setPassword(pwd);
+        accountInfo.sieveImapAccountSettings.setPassword(pwd);
+        accountInfo.sieveImapAccountSettings.setPort(interface->imapPort());
         u.setPort(interface->sievePort());
         QString authStr;
+        accountInfo.sieveImapAccountSettings.setAuthenticationType(static_cast<SieveImapAccountSettings::AuthenticationMode>((int)interface->authentication()));
         switch (interface->authentication()) {
         case MailTransport::Transport::EnumAuthenticationType::CLEAR:
         case MailTransport::Transport::EnumAuthenticationType::PLAIN:
@@ -113,15 +127,40 @@ QUrl KSieveUi::Util::findSieveUrlForAccount(const QString &identifier, bool with
         query.addQueryItem(QStringLiteral("x-mech"), authStr);
         const QString resultSafety = interface->safety();
         if (resultSafety == QLatin1String("None")) {
+            accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::Unencrypted);
             query.addQueryItem(QStringLiteral("x-allow-unencrypted"), QStringLiteral("true"));
+        } else if (resultSafety == QLatin1String("SSL")) {
+            accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::AnySslVersion);
+        } else if (resultSafety == QLatin1String("STARTTLS")) {
+            accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::TlsV1);
+        } else {
+            accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::Unencrypted);
         }
         u.setQuery(query);
         u = u.adjusted(QUrl::RemoveFilename);
         if (withVacationFileName) {
             u.setPath(u.path() + QLatin1Char('/') + QString(interface->sieveVacationFilename()));
         }
-        return u;
+        accountInfo.sieveUrl = u;
+        return accountInfo;
     } else {
+        QString server;
+        QString reply = interface->imapServer();
+        if (!reply.isEmpty()) {
+            server = reply;
+            server = server.section(QLatin1Char(':'), 0, 0);
+        } else {
+            return accountInfo;
+        }
+
+        const QString userName = interface->userName();
+        accountInfo.sieveImapAccountSettings.setServerName(server);
+        accountInfo.sieveImapAccountSettings.setUserName(userName);
+        accountInfo.sieveImapAccountSettings.setAuthenticationType(static_cast<SieveImapAccountSettings::AuthenticationMode>((int)interface->authentication()));
+        const QString pwd = provider->password(identifier);
+        accountInfo.sieveImapAccountSettings.setPassword(pwd);
+        accountInfo.sieveImapAccountSettings.setPort(interface->imapPort());
+
         QUrl u;
         u.setHost(interface->sieveAlternateUrl());
         u.setScheme(QStringLiteral("sieve"));
@@ -154,47 +193,60 @@ QUrl KSieveUi::Util::findSieveUrlForAccount(const QString &identifier, bool with
         }
         QUrlQuery query;
         query.addQueryItem(QStringLiteral("x-mech"), authStr);
+
         if (resultSafety == QLatin1String("None")) {
+            accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::Unencrypted);
             query.addQueryItem(QStringLiteral("x-allow-unencrypted"), QStringLiteral("true"));
+        } else if (resultSafety == QLatin1String("SSL")) {
+            accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::AnySslVersion);
+        } else if (resultSafety == QLatin1String("STARTTLS")) {
+            accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::TlsV1);
+        } else {
+            accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::Unencrypted);
         }
+
         u.setQuery(query);
 
         const QString resultCustomAuthentication = interface->sieveCustomAuthentification();
         if (resultCustomAuthentication == QLatin1String("ImapUserPassword")) {
             u.setUserName(interface->userName());
-            QDBusInterface resourceSettings(QLatin1String("org.freedesktop.Akonadi.Resource.") + identifier, QStringLiteral("/Settings"), QStringLiteral("org.kde.Akonadi.Imap.Wallet"));
-            QString pwd;
-            QDBusReply<QString> replyPass = resourceSettings.call(QStringLiteral("password"));
-            if (replyPass.isValid()) {
-                pwd = replyPass;
-            }
+            const QString pwd = provider->password(identifier);
             u.setPassword(pwd);
         } else if (resultCustomAuthentication == QLatin1String("CustomUserPassword")) {
-            QDBusInterface resourceSettings(QLatin1String("org.freedesktop.Akonadi.Resource.") + identifier, QStringLiteral("/Settings"), QStringLiteral("org.kde.Akonadi.Imap.Wallet"));
-            QString pwd;
-            QDBusReply<QString> replyPass = resourceSettings.call(QStringLiteral("sieveCustomPassword"));
-            if (replyPass.isValid()) {
-                pwd = replyPass;
-            }
+            const QString pwd = provider->sieveCustomPassword(identifier);
             u.setPassword(pwd);
             u.setUserName(interface->sieveCustomUsername());
+        } else {
+            qCWarning(LIBKSIEVE_LOG) << "resultCustomAuthentication undefined " << resultCustomAuthentication;
         }
         u = u.adjusted(QUrl::RemoveFilename);
         if (withVacationFileName) {
             u.setPath(u.path() + QLatin1Char('/') + QString(interface->sieveVacationFilename()));
         }
-        return u;
+        accountInfo.sieveUrl = u;
+        return accountInfo;
     }
 }
 
-Akonadi::AgentInstance::List KSieveUi::Util::imapAgentInstances()
+QStringList KSieveUi::Util::sieveImapResourceNames()
 {
-    Akonadi::AgentInstance::List relevantInstances;
-    foreach (const Akonadi::AgentInstance &instance, Akonadi::AgentManager::self()->instances()) {
-        if (instance.type().mimeTypes().contains(KMime::Message::mimeType()) &&
-                instance.type().capabilities().contains(QStringLiteral("Resource")) &&
-                !instance.type().capabilities().contains(QStringLiteral("Virtual"))) {
+    const QVector<KSieveUi::SieveImapInstance> lst = KSieveUi::Util::sieveImapInstances();
+    QStringList resourceNames;
+    resourceNames.reserve(lst.count());
+    for (const KSieveUi::SieveImapInstance &type : lst) {
+        resourceNames << type.identifier();
+    }
+    return resourceNames;
+}
 
+QVector<KSieveUi::SieveImapInstance> KSieveUi::Util::sieveImapInstances()
+{
+    const QVector<KSieveUi::SieveImapInstance> allInstances = KSieveUi::SieveImapInstanceInterfaceManager::self()->sieveImapInstanceList();
+    QVector<KSieveUi::SieveImapInstance> relevantInstances;
+    for (const KSieveUi::SieveImapInstance &instance : allInstances) {
+        if (instance.mimeTypes().contains(KMime::Message::mimeType())
+            && instance.capabilities().contains(QStringLiteral("Resource"))
+            && !instance.capabilities().contains(QStringLiteral("Virtual"))) {
             if (PimCommon::Util::isImapResource(instance.identifier())) {
                 relevantInstances << instance;
             }
@@ -230,7 +282,7 @@ bool Util::hasKep14Support(const QStringList &sieveCapabilities, const QStringLi
     }
 
     bool hasUserScript = false;
-    foreach (const QString &script, availableScripts) {
+    for (const QString &script : availableScripts) {
         if (script.isEmpty()) {
             continue;
         }
@@ -247,11 +299,27 @@ bool Util::hasKep14Support(const QStringList &sieveCapabilities, const QStringLi
 bool Util::isKep14ProtectedName(const QString &name)
 {
     const QString n = name.split(QLatin1Char('.')).first().toLower();
-    if (n == QStringLiteral("master") ||
-            n == QStringLiteral("user") ||
-            n == QStringLiteral("management")) {
+    if (n == QStringLiteral("master")
+        || n == QStringLiteral("user")
+        || n == QStringLiteral("management")) {
         return true;
     }
     return false;
 }
 
+QDebug Util::operator <<(QDebug d, const Util::AccountInfo &info)
+{
+    d << "sieveImapAccountSettings " << info.sieveImapAccountSettings;
+    d << "url " << info.sieveUrl.toString();
+    return d;
+}
+
+bool Util::AccountInfo::operator==(const Util::AccountInfo &other) const
+{
+    const bool result = (other.sieveImapAccountSettings == sieveImapAccountSettings)
+                        && (other.sieveUrl == sieveUrl);
+    if (!result) {
+        qCDebug(LIBKSIEVE_LOG) << "actual :" << *this << "\n other :" << other;
+    }
+    return result;
+}
