@@ -18,28 +18,25 @@
 
 #include <QDialog>
 
-template <typename T> class QList;
+template<typename T> class QList;
 class QDate;
 class QTime;
 
-namespace KMime
-{
-namespace Types
-{
+namespace KMime {
+namespace Types {
 struct AddrSpec;
 typedef QVector<AddrSpec> AddrSpecList;
 }
 }
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class VacationEditWidget;
 class VacationDialog : public QDialog
 {
     Q_OBJECT
 
 public:
-    explicit VacationDialog(const QString &caption, QWidget *parent = Q_NULLPTR);
+    explicit VacationDialog(const QString &caption, QWidget *parent = nullptr);
     ~VacationDialog();
 
     void enableDomainAndSendForSpam(bool enable = true);
@@ -100,7 +97,6 @@ private:
 
     VacationEditWidget *mVacationEditWidget;
 };
-
 }
 
 #endif
