@@ -27,15 +27,14 @@
 
 using namespace KSieveUi;
 
-CustomManageSieveWidget::CustomManageSieveWidget(QWidget *parent)
+CustomManageSieveWidget::CustomManageSieveWidget(SieveImapPasswordProvider *passwordProvider, QWidget *parent)
     : KSieveUi::ManageSieveWidget(parent)
+    , mPasswordProvider(passwordProvider)
 {
-
 }
 
 CustomManageSieveWidget::~CustomManageSieveWidget()
 {
-
 }
 
 bool CustomManageSieveWidget::refreshList()
@@ -52,8 +51,8 @@ bool CustomManageSieveWidget::refreshList()
         last = new SieveTreeWidgetItem(treeView(), last);
         last->setIcon(0, QIcon::fromTheme(QStringLiteral("network-server")));
 
-        const KSieveUi::Util::AccountInfo info = KSieveUi::Util::fullAccountInfo(type.identifier(), false);
-        const QUrl u  = info.sieveUrl;
+        const KSieveUi::Util::AccountInfo info = KSieveUi::Util::fullAccountInfo(type.identifier(), mPasswordProvider, false);
+        const QUrl u = info.sieveUrl;
         if (u.isEmpty()) {
             QTreeWidgetItem *item = new QTreeWidgetItem(last);
             item->setText(0, i18n("No Sieve URL configured"));
